Why earthkit?
=============


**earthkit** offers **multiple interoperable** :ref:`software components <components>` built on top of
well-established open-source Python libraries like numpy, pandas and matplotlib. earthkit also integrates
and leverages the robust and operations-ready software stack that is familiar to ECMWF production systems
(e.g. ecCodes, FDB, etc).

The interface of :ref:`earthkit components <components>` is designed to be high-level in order to provide common tools to support activities across ECMWF and beyond. The design of the components also takes **scalability** into account, so researchers can enjoy efficiency whilst providing easier transfer to operations.

**earthkit** is still under development but a selection of core components are approaching
a version 1.0.0 release and have release candidates available on PyPi and their GitHub repositories.
